.. _contribexample:

Examples
========

The source for C++ examples are located in ``/example`` and
Python examples in ``/python/example``. You can add yours in the same
way you would contribute code; please see the :ref:`contribpr` section.

Especially when adding new functionality, consider adding an example to demonstrate its use.

.. _contribexample-tut:

Tutorials
---------

Tutorials are examples with an associated :ref:`documentation <contribdoc>` under ``/doc/tutorial``
explaining the goal of the example and guiding the reader through the code. When you add an example,
consider writing a tutorial page.
